Cletus is a library to help with write commmand line python programs.

More info is on the cletus wiki here:
https://github.com/kenfar/cletus/wiki

Installation
============

-  Using `pip <http://www.pip-installer.org/en/latest/>`__ (preferred)
   or
   `easyinstall <http://peak.telecommunity.com/DevCenter/EasyInstall>`__:

   :sub:`~` $ pip install cletus $ easy\_install cletus :sub:`~`

-  Or install manually from
   `pypi <https://pypi.python.org/pypi/cletus>`__:

   :sub:`~` $ mkdir ~$ wget
   https://pypi.python.org/packages/source/d/cletus/cletus-0.1.tar.gz $
   tar -xvf easy\_install cletus $ cd ~-\* $ python setup.py install
   :sub:`~`

Dependencies
============

-  Python 2.7

Licensing
=========

-  Cletus uses the BSD license - see the separate LICENSE file for
   further information

Copyright
=========

-  Copyright 2013, 2014 Ken Farmer

